%global _lto_cflags %{nil}
%global __provides_exclude_from ^(%{python3_sitearch}/.*\\.so)$
%{?perl_default_filter}

Summary:       Software framework for cross-language services development
Name:          thrift
Version:       0.14.0
Release:       7%{?dist}
License:       Apache-2.0 AND BSD-3-Clause AND Zlib
URL:           https://thrift.apache.org/
Source0:       https://archive.apache.org/dist/%{name}/%{version}/%{name}-%{version}.tar.gz
Source1:       https://raw.github.com/apache/%{name}/%{version}/bootstrap.sh

Patch0001:     thrift-char.patch
Patch3000:     configure-java-prefix.patch

BuildRequires: make autoconf automake gcc-c++ bison flex
BuildRequires: boost-devel boost-static glib2-devel zlib-devel
BuildRequires: libevent-devel libstdc++-devel libtool openssl-devel qt5-qtbase-devel


%description
The Apache Thrift software framework for cross-language services
development combines a software stack with a code generation engine to
build services that work efficiently and seamlessly between C++, Java,
Python and other languages.


%package devel
Summary: Development files for %{name}
Requires: %{name} = %{version}-%{release}
Requires: pkgconfig
Requires: boost-devel

%description devel
The %{name}-devel package contains libraries and header files for
developing applications that use %{name}.

%package        qt
Summary:        Qt support for %{name}
Requires:       %{name} = %{version}-%{release}

%description    qt
The %{name}-qt package contains Qt bindings for %{name}.

%package        glib
Summary:        GLib support for %{name}
Requires:       %{name} = %{version}-%{release}

%description    glib
The %{name}-qt package contains GLib bindings for %{name}.

%package -n python3-%{name}
Summary:        Python 3 support for %{name}
BuildRequires:  python3-devel python3-setuptools
Requires:       %{name} = %{version}-%{release}
Requires:       python3

%description -n python3-%{name}
The python3-%{name} package contains Python bindings for %{name}.

%package -n perl-%{name}
Summary:        Perl support for %{name}
Provides:       perl(Thrift) = %{version}-%{release}
BuildRequires:  perl(Bit::Vector) perl(Class::Accessor) perl(ExtUtils::MakeMaker) perl-generators
Requires:       perl(:MODULE_COMPAT_%perl_version)
Requires:       perl(Bit::Vector) perl(Encode) perl(HTTP::Request) perl(IO::Select)
Requires:       perl(IO::Socket::INET) perl(IO::String) perl(LWP::UserAgent) perl(POSIX)
Requires:       perl(base) perl(constant) perl(strict) perl(utf8) perl(warnings)
Provides:       perl(Thrift::Exception) perl(Thrift::MessageType) perl(Thrift::Type)
BuildArch:      noarch

%description -n perl-%{name}
The perl-%{name} package contains Perl bindings for %{name}.


%prep
%autosetup -p1
sed -i -e 's/^AC_PROG_LIBTOOL/LT_INIT/g' configure.ac
find . -name \*.cpp -or -name \*.cc -or -name \*.h | xargs -r chmod 644
cp -p %{SOURCE1} bootstrap.sh

echo 'libthrift_c_glib_la_LIBADD = $(GLIB_LIBS) $(GOBJECT_LIBS) -L../cpp/.libs ' >> lib/c_glib/Makefile.am
echo 'libthriftqt5_la_LIBADD = $(QT_LIBS) -lthrift -L.libs' >> lib/cpp/Makefile.am
echo 'libthriftz_la_LIBADD = $(ZLIB_LIBS) -lthrift -L.libs' >> lib/cpp/Makefile.am
echo 'EXTRA_libthriftqt5_la_DEPENDENCIES = libthrift.la' >> lib/cpp/Makefile.am
echo 'EXTRA_libthriftz_la_DEPENDENCIES = libthrift.la' >> lib/cpp/Makefile.am

sed -i 's|ANT_VALID=.*|ANT_VALID=1|' aclocal/ax_javac_and_java.m4

shopt -s globstar
sed -i -E 's@^(#!.*/env) *python *$@\1 python3@' **/*.py


%build
export PY_PREFIX=%{_prefix}
export PERL_PREFIX=%{_prefix}
export PHP_PREFIX=%{php_extdir}
export JAVA_PREFIX=%{_javadir}
export RUBY_PREFIX=%{_prefix}
export GLIB_LIBS=$(pkg-config --libs glib-2.0)
export GLIB_CFLAGS=$(pkg-config --cflags glib-2.0)
export GOBJECT_LIBS=$(pkg-config --libs gobject-2.0)
export GOBJECT_CFLAGS=$(pkg-config --cflags gobject-2.0)

find %{_builddir} -name rebar -delete
find . -name Makefile\* -exec sed -i -e 's/[.][/]rebar/rebar/g' {} \;

sed -i 's|-Dinstall.javadoc.path=$(DESTDIR)$(docdir)/java|-Dinstall.javadoc.path=$(DESTDIR)%{_javadocdir}/%{name}|' lib/java/Makefile.*
sed -i 's|$(INSTALL) $$p|$(INSTALL) --mode 644 $$p|g' lib/erl/Makefile.am
sh ./bootstrap.sh

export PYTHON=%{_bindir}/python3
%configure --disable-dependency-tracking --disable-static --with-boost=/usr \
  --docdir=%{?_pkgdocdir}%{!?_pkgdocdir:%{_docdir}/%{name}-%{version}} \
  --without-java --without-ruby --without-erlang --without-go --without-php --without-lua

sed -i -e 's/ -shared / -Wl,--as-needed\0/g' libtool

%make_build


%install
%make_install
find %{buildroot} -name '*.la' -delete
find %{buildroot} -name fastbinary.so | xargs -r chmod 755
find %{buildroot} -name \*.erl -or -name \*.hrl -or -name \*.app | xargs -r chmod 644
find %{buildroot} -name \*.jar -a \! -name \*thrift\* -delete
find %{buildroot} -name \*.pod -delete
find %{buildroot} -name .packlist -delete
find %{buildroot}/usr/lib/perl5 -type d -empty -delete
mkdir -p %{buildroot}/%{perl_vendorlib}/
mv %{buildroot}/usr/lib/perl5/* %{buildroot}/%{perl_vendorlib}
find %{buildroot} -name Thread.h -exec chmod a-x '{}' \;
find %{buildroot} -name \*.py -exec grep -q /usr/bin/env {} \; -print | xargs -r chmod 755


%files
%license LICENSE
%doc NOTICE
%{_bindir}/thrift
%{_libdir}/libthrift-%{version}.so
%{_libdir}/libthriftz-%{version}.so
%{_libdir}/libthriftnb-%{version}.so

%files glib
%{_libdir}/libthrift_c_glib.so
%{_libdir}/libthrift_c_glib.so.*

%files qt
%{_libdir}/libthriftqt5.so
%{_libdir}/libthriftqt5-%{version}.so

%files devel
%license LICENSE
%doc NOTICE
%{_includedir}/thrift
%{_libdir}/*.so
%{_libdir}/*.so.0
%{_libdir}/*.so.0.0.0
%exclude %{_libdir}/lib*-%{version}.so
%{_libdir}/pkgconfig/thrift-z.pc
%{_libdir}/pkgconfig/thrift-qt5.pc
%{_libdir}/pkgconfig/thrift-nb.pc
%{_libdir}/pkgconfig/thrift.pc
%{_libdir}/pkgconfig/thrift_c_glib.pc

%files -n perl-%{name}
%license LICENSE
%doc NOTICE
%{perl_vendorlib}/Thrift
%{perl_vendorlib}/Thrift.pm

%files -n python3-%{name}
%license LICENSE
%doc NOTICE
%{python3_sitearch}/%{name}
%{python3_sitearch}/%{name}-%{version}-py%{python3_version}.egg-info


%changelog
* Tue Sep 19 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 0.14.0-7
- Rebuilt for python 3.11

* Fri Sep 08 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 0.14.0-6
- Rebuilt for OpenCloudOS Stream 23.09

* Tue Aug 01 2023 rockerzhu rockerzhu@tencent.com - 0.14.0-5
- Rebuilt for boost 1.82.0

* Fri Apr 28 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 0.14.0-4
- Rebuilt for OpenCloudOS Stream 23.05

* Fri Mar 31 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 0.14.0-3
- Rebuilt for OpenCloudOS Stream 23

* Thu Feb 16 2023 Shuo Wang <abushwang@tencent.com> - 0.14.0-2
- remove unused buildrequires: texlive

* Fri Dec 16 2022 Miaojun Dong <zoedong@tencent.com> - 0.14.0-1
- initial build
